#!/bin/sh
#\
exec wish -f "$0" "$@"

# ------------------------------------------------
# Load the extension libraries for the bltgraph
# and for the spectrometer 
# -----------------------------------------------

load libBLT24.so
load libs2000.so
namespace import blt::*

# ------------------------------------------------------
# Create vectors and graphs for the data
# Y: Intensity from spectrometer corrected by CALIB
# X: Pixelnumber 0 to 2047
# XNM: Wavelenght in Nanometers corresponding to Pixels
# CALIB: 1/sensivity of pixels
# -----------------------------------------------------

vector Y X XNM TMP CALIB(2048)
set CALIB(0:2047) .0001 
X seq 0 2047

button .exit -text Exit -command { exit 0 }
graph .graph -width 500 -height 200 -title "Spectrum" 
.graph xaxis configure  -title "nm"
.graph element create line -xdata XNM -ydata Y -symbol none
pack .graph .exit -expand true -fill both

# --------------------------------------------------------
# calculate nanometers from pixelnumber
# This is done with a correction polynom
# please insert the correct values for your spectrometer
# from the datasheet delivered with your spectrometer
# --------------------------------------------------------

proc calcXNM { } {
	set lambda_null 624.686491
	set lambda_factor 0.35986096
	set lambda_factor2 -2.276e-5
        TMP set [X * X]
        TMP set [TMP * $lambda_factor2 ]
        XNM set [X * $lambda_factor]
        XNM set [XNM + $lambda_null]
        XNM set [XNM + TMP]
}
calcXNM

# ------------------------------------------------------------
# This is the interesting part of this demo file:
# open the spectrometer in the correct manner, then
# connect vector Y to the spectrometer
# multiply the spectrometer data with vector CALIB 
# before writing them to vector Y ( for sensivity calibration ) 
# ------------------------------------------------------------

set spectro [open /dev/adc500_0 r+] 
s2000_link_vector $spectro Y CALIB
